@@ -3,10 +3,12 @@ import json
 import pandas as pd
 
 # return answer as dataframe 
-def answer(token, question): 
-    url = "https://spawnerapi.com/answer/" + token
+def answer(question): 
+    url = "https://spawnerapi.com/answer"
     trade_list = {"text": question}
     headers={'Content-type':'application/json'}
     r = requests.post(url, headers=headers, data=json.dumps(trade_list))
     content = r.text
-    return pd.read_json(content, orient='records')
\ No newline at end of file
+    df = pd.read_json(content, orient='records')
+    df = df.drop(columns=['chart_type', 'condensed_data'])
+    return df
\ No newline at end of file
